@@ -30,3 +30,9 @@ class MessageService:
         """
         return self.__client.call("eleme.message.queryFailedMessageLog", {"request": request})
 
+    def test_interface(self):
+        """
+        测试接口，勿动
+        """
+        return self.__client.call("eleme.message.testInterface", {})
+
